<?php 
/**
* 
* CashPress
* 
* Special function for validating and sending all forms on the site.
* Also uses wordpress filters to sanitize data and protect against spam,
* and includes error and success messages
* 
* Last Update: Version 1.1
* 
**/

function csp_email($mail_data){

// Get csp admin settings
$company_options = get_option('csp_company');
$csp_settings = get_option('csp_settings');


//Clear old errors
$errors = 0;

//Error Messages
$invalid_email = __('<br/><h3 style="color:red;" >Invalid Email Address</h3><p>Please re-check your email address, it looks like the one you entered is invalid :-)</p>','cashpress');

$no_name = __('<br/><h3 style="color:red;" >No Name Entered</h3><p>Oops! It looks like you forgot your name, please check the form and try sending again :-)</p>','cashpress');

$no_subject = __('<br/><h3 style="color:red;" >No Subject Entered</h3><p>Oops! It looks like you forgot your subject, please check the form and try sending again :-)</p>','cashpress');

$no_message = __('<br/><h3 style="color:red;" >Invalid Field Entered</h3><p>IT looks like you filled out a field you should not have, which means you are probably a spam bot. If you reached this page as a mistake, please email the site owner.</p>','cashpress');

$bad_bot = __('<br/><h3 style="color:red;" >No Subject Entered</h3><p>Oops! It looks like you forgot to type a message, please check the form and try sending again :-)</p>','cashpress');

$invalid_chars = __('<br/><h3 style="color:red;" >Invalid Characters Entered</h3><p>Oops! It looks like you entered something in the "name" field that is not safe for forms. Please check that you have entered everything correctly and try again :-)</p>','cashpress');

$bad_nonce = __('<br/><h3 style="color:red;" >Invalid Form Submission</h3><p>Oops! It looks like the form you submitted was not from a page on this domain. Please refresh the page you were trying to submit and click send again.</p>','cashpress');

$bad_captcha = __('<br/><h3 style="color:red;" >Incorrect Captcha Entered</h3><p>Oops! It looks like the captcha you entered was incorrect. Please check the words you entered and try again :-)</p>','cashpress');

$bad_question = __('<br/><h3 style="color:red;" >Incorrect Spam Question</h3><p>Oops! It looks like the answer you entered was incorrect. Please check the question and try again :-)</p>','cashpress');

// Validate email
if (!is_email($mail_data['visitor_email'])){
	$errors = 1;
	$_POST['error_message'] = $invalid_email;
	echo $invalid_email;
}

if ($mail_data['visitor_name'] == ""){
	$errors = 1;
	$_POST['error_message'] = $no_name;
	echo $no_name;
}

if ($mail_data['form_type'] == "send_invoice" && $mail_data['mail_subject'] == ""){
	$errors = 1;
	$_POST['error_message'] = $no_subject;
	echo $no_subject;
}

if ($mail_data['form_type'] == "send_invoice" && $mail_data['invoice_message'] == ""){
	$errors = 1;
	$_POST['error_message'] = $no_message;
	echo $no_message;
}

$nonce = $_POST['message_test'];
if (!wp_verify_nonce($nonce, 'csp-contact-form')){
	$errors = 1;
	$_POST['error_message'] = $bad_nonce;
	echo $bad_nonce;
}

//Captcha & Spam Prevention for Version 1.1


if ($csp_settings['captcha'] == 'recaptcha' && $mail_data['form_type'] != "Contact Form:"){
	require_once('recaptchalib.php');
	$privatekey = "6LfTNr0SAAAAAJQ8dlld9ShgDv0ZLik5kzq-EH5Q";
	$resp = recaptcha_check_answer ($privatekey,
	                                $_SERVER["REMOTE_ADDR"],
	                                $_POST["recaptcha_challenge_field"],
	                                $_POST["recaptcha_response_field"]);
	
	if (!$resp->is_valid) {
		$errors = 1;
		$_POST['error_message'] = $bad_captcha;
		echo $bad_captcha;
	}
}

if ($csp_settings['captcha'] == 'question') {
	if (strtolower($mail_data['botquestion']) != strtolower($csp_settings['botanswer']) ){
			$errors = 1;
			$_POST['error_message'] = $bad_question;
			echo $bad_question;
	}
}



$safename = sanitize_user($mail_data['visitor_name'], true);

// Check for no errors
if ($errors == 0){

if ($mail_data['form_type'] != "send_invoice"){
// Configuration Settings
	$SendFrom =    ($safename . " <" . $mail_data['visitor_email'] .">");
	$SendTo =      $company_options['contactemail'];
	$SubjectLine = ($mail_data['form_type'] . " " . $safename);

// Build Message Body from Web Form Input
	foreach ($mail_data as $Field=>$Value)
		$MsgBody .= "$Field: $Value\n\n";
		$MsgBody .= "\n" . @gethostbyaddr($_SERVER["REMOTE_ADDR"]) . "\n" .
		$_SERVER["HTTP_USER_AGENT"];
		$MsgBody = htmlspecialchars($MsgBody, ENT_NOQUOTES);  //make safe

// Send E-Mail
mail($SendTo, $SubjectLine, $MsgBody, "From: $SendFrom");

} else {

// Check form code
	if ($mail_data['name'] != ""){
	echo $bad_bot;
		die('Please only access this script directly from the invoices page');
	}

// Configuration Settings
	$safemail = 	sanitize_user($company_options['businessname'], true);
	$SendFrom =    ($safemail . " <" . $company_options['contactemail'] .">");
	$SendTo =      $mail_data['visitor_email'];
	$SubjectLine = sanitize_user($mail_data['mail_subject'], true);

// Build Message Body from Web Form Input
		$MsgBody .= $mail_data['invoice_message'];
		$MsgBody = htmlspecialchars($MsgBody, ENT_NOQUOTES);  //make safe

// Send E-Mail
mail($SendTo, $SubjectLine, $MsgBody, "From: $SendFrom");

}

// Update Proposal Status (if it's a proposal approve)
if($mail_data['form_type'] == 'Proposal Approved:'){
$proposal_post = get_post_by_title($_POST['proposal_title']);
update_post_meta($proposal_post->ID, "proposalstatus", 'Approved');
}

//Provide feedback
echo __('<div id="thankyouret"><br/><h3>Your Message has Been Sent!</h3><p>We will get back to you as soon as we can with a reply.</p></div>','cashpress');

$_POST['visitor_email'] = "" ;
$_POST['visitor_name'] = "" ;
$_POST['visitor_message'] = "" ;
$_POST['visitor_budget'] = "";
$_POST['invoice_message'] = "" ;
$_POST['mail_subject'] = "" ;
$_POST['name'] = "" ;
$_POST['hash'] = "" ;
$_POST["recaptcha_challenge_field"] = "";
$_POST["recaptcha_response_field"] = "";

}
}

?>
